@@ -33,10 +33,10 @@ def delete_app(napp: str):
     """
     if napp:
         napp = secure_filename(napp).lower().replace('-api', '') + '-project'
-        if input('💩 Are you sure you want to delete the %s (Y/N): ' % napp).lower() == 'y':
+        if input('Are you sure you want to delete the %s (Y/N): ' % napp).lower() == 'y':
             shutil.rmtree(napp)
     else:
-        print("you need to specify the api name 🤬")
+        print("you need to specify the api name")
 
 
 def create_app(napp: str):
@@ -45,19 +45,19 @@ def create_app(napp: str):
     """
     if napp:
         CDIR = path.dirname(path.realpath(__file__))
-        acode = input('app code 👉: ').strip()
-        port = input('app port 👉: ').strip() or '5000'
+        acode = input('app code: ').strip()
+        port = input('app port: ').strip() or '5000'
         napp = secure_filename(napp).lower().replace('-api', '')
         rootProject = napp + '-project'  # carpeta de proyecto
         rootPath = path.join(rootProject, napp + '-api')  # carpeta del api
         # crea carpetas
         for dname in ('', 'modules', 'resources', '__temp__'):
-            print("🚩 creating > " + (dname or rootPath))
+            print("creating > " + (dname or rootPath))
             makedirs(path.join(rootPath, dname))
         DRESOURCES = path.join(CDIR, 'resources')
         for name in listdir(DRESOURCES):
             if name != '__pycache__':
-                print("🚩 creating > " + name)
+                print("creating > " + name)
                 npath = path.join(DRESOURCES, name)
                 if path.isdir(npath):  # si es directorio lo copia todo
                     shutil.copytree(npath, path.join(rootPath, name), dirs_exist_ok=True, ignore=shutil.ignore_patterns('__pycache__', '*.pyc'))
@@ -71,6 +71,6 @@ def create_app(napp: str):
                     elif name.endswith('.pyc') is False:
                         shutil.copyfile(npath, path.join(rootPath, name))
         create_virtual_env(napp, rootProject, rootPath)  # crea entorno e instala dependencias
-        print("\n\nhappy coding 😎🤟\n\n")
+        print("\n\nhappy coding\n\n")
     else:
-        print("you need to specify the api name 🤬")
+        print("you need to specify the api name")
